import React from 'react'
import axios from 'axios'

function MoviePosters(props) {
  const movies = props.movies;
  return (
    <div className="col-xs-5 col-md-8">
      <div className="row">
        {movies.map((movie, index) =>
            <MoviePoster
              data={movie}
              key={movie.ID}
              onClick={ (e) => props.onClick(e, index) }
            />
        )}
      </div>
    </div>
  );
}

function MoviePoster(props) {
  const imgUrl = '/img/movies/' + props.data.imdb_id +'.jpg';
  const selected = props.data.selected ? ' thumbnail-selected' : '';
  const imgClass = 'thumbnail' + selected;
  return (
    <div className="col-xs-12 col-md-3">
      <a className={imgClass}>
        <img src={imgUrl} onClick={props.onClick}/>
      </a>
    </div>
  );
}

function MovieDetails(props) {
  return (
    <div className="col-xs-7 col-md-4">
      <div className="movie-detail affix">
        <h1 className="hidden-xs">{props.data.title}</h1>
        <h3 className="visible-xs">{props.data.title}</h3>
        <p>
          <i className="fa fa-clock-o"></i>
          {props.data.runtime} min
        </p>
        <p>
          <i className="fa fa-star-o"></i>
          {props.data.rating} <small>({props.data.votes} counts)</small>
        </p>
        <p className="movie-plot">{props.data.plot}</p>
      </div>
    </div>
  );
}

export default class MovieList extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      movies: [],
      currentMovie: {},
    };
    this.handleClick = this.handleClick.bind(this);
  }
  handleClick(e,i) {
    e.preventDefault();
    let movies = this.state.movies.slice();
    this.setMovies(movies, i);
  }
  setMovies(movies, index) {
    let currentMovie = {};
    movies.map(function(movie) {
      movie.selected = false;
      return {movie: movie};
    });
    if (!index && movies.length) {
      index = 0;
      currentMovie = movies[0];
    }
    if (index !== null) {
      currentMovie = movies[index];
      movies[index].selected = true;
    }
    this.setState({
      movies: movies,
      currentMovie: currentMovie,
    });
  }
  componentDidMount() {
    var _this = this;
    this.serverRequest =
      axios
      .get("/movies/explore/popular")
      .then(function(result) {
        _this.setMovies(result.data.Data.movies);
      })
  }
  componentWillUnmount() {
    this.serverRequest.abort();
  }
  render() {
    return (
      <div className="row" id="movie-library">
        <MoviePosters movies={this.state.movies} onClick={this.handleClick}/>
        <MovieDetails data={this.state.currentMovie} />
      </div>
    );
  }
}
